<?php

namespace App\Api\V1;

use App\Api\V1\Middleware\AuthMiddleware;
use App\Api\V1\Responses\ApiResponse;

/**
 * Routeur pour les API V1.
 */
class Router
{
    private $routes = [];
    private $authMiddleware;

    public function __construct()
    {
        $this->authMiddleware = new AuthMiddleware();
    }

    /**
     * Enregistre une route.
     */
    public function addRoute($method, $path, $controller, $action, $requiresAuth = false)
    {
        $this->routes[] = [
            'method' => $method,
            'path' => $path,
            'controller' => $controller,
            'action' => $action,
            'requiresAuth' => $requiresAuth
        ];
    }

    /**
     * Dispatche la requête vers le bon contrôleur.
     */
    public function dispatch()
    {
        $requestMethod = $_SERVER['REQUEST_METHOD'];
        $requestUri = parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH);
        
        // Retirer le préfixe /api/v1
        $requestUri = preg_replace('#^/api/v1#', '', $requestUri);
        if (empty($requestUri)) {
            $requestUri = '/';
        }

        foreach ($this->routes as $route) {
            if ($this->matchRoute($route, $requestMethod, $requestUri)) {
                // Vérifier l'authentification si nécessaire
                if ($route['requiresAuth'] && !$this->authMiddleware->handle()) {
                    return; // Le middleware a déjà envoyé la réponse
                }

                // Extraire les paramètres de l'URL
                $params = $this->extractParams($route['path'], $requestUri);
                
                // Instancier le contrôleur et appeler l'action
                $controllerClass = "App\\Api\\V1\\Controllers\\" . $route['controller'];
                
                if (class_exists($controllerClass)) {
                    $controller = new $controllerClass();
                    $action = $route['action'];
                    
                    if (method_exists($controller, $action)) {
                        // Appeler l'action avec les paramètres
                        call_user_func_array([$controller, $action], $params);
                        return;
                    }
                }
                
                ApiResponse::serverError('Controller or action not found');
                return;
            }
        }

        ApiResponse::notFound('API endpoint not found');
    }

    /**
     * Vérifie si une route correspond à la requête.
     */
    private function matchRoute($route, $method, $uri)
    {
        if ($route['method'] !== $method) {
            return false;
        }

        // Convertir le pattern de route en regex
        $pattern = preg_replace('/\{([^}]+)\}/', '([^/]+)', $route['path']);
        $pattern = '#^' . $pattern . '$#';
        
        return preg_match($pattern, $uri);
    }

    /**
     * Extrait les paramètres de l'URL.
     */
    private function extractParams($routePath, $uri)
    {
        $pattern = preg_replace('/\{([^}]+)\}/', '([^/]+)', $routePath);
        $pattern = '#^' . $pattern . '$#';
        
        if (preg_match($pattern, $uri, $matches)) {
            // Retirer le premier élément (correspondance complète)
            array_shift($matches);
            return $matches;
        }
        
        return [];
    }
}