import { create } from 'zustand'
import { persist } from 'zustand/middleware'
import { AuthUser, LoginCredentials } from '../types'
import { authApi } from '../services/api'
import toast from 'react-hot-toast'

interface AuthState {
  user: AuthUser | null
  isAuthenticated: boolean
  isLoading: boolean
  login: (credentials: LoginCredentials) => Promise<boolean>
  logout: () => void
  updateUser: (user: Partial<AuthUser>) => void
}

export const useAuth = create<AuthState>()(
  persist(
    (set, get) => ({
      user: null,
      isAuthenticated: false,
      isLoading: false,

      login: async (credentials: LoginCredentials) => {
        set({ isLoading: true })
        try {
          const response = await authApi.login(credentials)
          if (response.success && response.data) {
            set({
              user: response.data,
              isAuthenticated: true,
              isLoading: false,
            })
            toast.success('Successfully logged in!')
            return true
          } else {
            toast.error(response.message || 'Login failed')
            set({ isLoading: false })
            return false
          }
        } catch (error) {
          console.error('Login error:', error)
          toast.error('Login failed. Please try again.')
          set({ isLoading: false })
          return false
        }
      },

      logout: () => {
        authApi.logout().catch(console.error)
        set({
          user: null,
          isAuthenticated: false,
          isLoading: false,
        })
        toast.success('Successfully logged out!')
      },

      updateUser: (userData: Partial<AuthUser>) => {
        const currentUser = get().user
        if (currentUser) {
          set({
            user: { ...currentUser, ...userData },
          })
        }
      },
    }),
    {
      name: 'auth-storage',
      partialize: (state) => ({
        user: state.user,
        isAuthenticated: state.isAuthenticated,
      }),
    }
  )
)